@@ -100,6 +100,8 @@ public:
 	    *enviCova,//!< QAction ENVI only for covalent contacts
 	    *wireButt,//!< QAction show atoms while rotation in wire mode
 	    *invSelection,//!< QAction invert selection
+        *cntrPlot,    
+        *nocntrPlot,
         *hideBeLo,//!< hide/show  BEDE and LONE objects
         *useTextureLabels,//!< alternative to Qt renderText render Labels on BillBoard textures
         *shortLabels,//!< Labels without residue number or symmery flag are considered short
@@ -107,6 +109,8 @@ public:
     QToolButton *enviButt;//!< Button to clear the envi -ronment.
     QToolButton *enviSelect;//!< Button to select the envi -ronment.
     QList<V3>enviPositions;//!<List of atom postions of an envi-ronment.
+    QList<V3> cont;
+    QMap<int,GLfloat> contval;
     QList<int>enviKat;//!< List of categorie:qs of contacts in an envi-ronment.
     V3 enviP0;//!< coordinate used for envi.
     QMenu *sfacMenu;//!< a sub menu to change the element of a specified atom.
