@@ -141,10 +141,15 @@ CodeEditor::CodeEditor(QWidget *parent) : QPlainTextEdit(parent), c(0){
 }
 
 CodeEditor::~CodeEditor(){
+  printf("CodeEditor will close%d\n",__LINE__);
   disconnect(this);
+  //printf("ce%d\n",__LINE__);
   delete lineNumberArea;
+  //printf("ce%d\n",__LINE__);
   delete afixHighlightArea;
+  //printf("ce%d\n",__LINE__);
   delete highlighter;
+  printf("CodeEditor closed. %d %p\n",__LINE__,chgl);
 
 }
 
@@ -911,6 +916,161 @@ void CodeEditor::changeSortierWeise(QAction* action){
   chgl->mol->einstellung->endGroup();
 }
 
+QString CodeEditor::sortLabelList(CEnvironment &asymm, MyAtom &tatze){
+    if (asymm.isEmpty()) return "HKLF";
+    QMap<long double,MyAtom> atomSortMap;
+    long double lodo=0.0l;
+    int amax = asymm.size();
+
+    int t1=0,t2=0;
+    for (int i=0; i < asymm.size(); i++){
+      if (asymm.at(i).an<0) continue;
+      t1++;
+      QString s1 = asymm.at(i).Label.section('_',0,0);
+      s1.remove(0,chgl->mol->pse(asymm.at(i).an).size());
+      int n1 = s1.section(QRegExp("\\D"),0,0).toInt();
+      int r1 = 0 ;
+      char cc[10];
+      strncpy(cc,s1.section(QRegExp("\\d+"),1,-1).toStdString().c_str(),4);
+      for (size_t k=0; k<strlen(cc);k++) {r1*=256;r1+=(size_t)cc[k];}
+      switch (sortierWeise){
+        case 1:
+          lodo=asymm.at(i).resiNr*99*amax+
+                  asymm.at(i).part*amax+
+                  n1+
+                  ((110-asymm.at(i).an)/220.0l)+
+                  (r1 / 50000.0l);//46656
+          atomSortMap.insertMulti(lodo,asymm.at(i));
+          break;
+        case 2:
+          lodo=asymm.at(i).resiNr*99*amax+
+                  asymm.at(i).part*amax+
+                  n1/999.0l+
+                  ((110-asymm.at(i).an))+
+                  (r1 / 50000.0l);//46656
+
+          atomSortMap.insertMulti(lodo,asymm.at(i));
+          //printf("##= %Lf %d %d %d %d %d\n",lodo,asymm.at(i).resiNr,asymm.at(i).part,n1,(110-asymm.at(i).an),r1);
+          break;
+        case 3:
+          lodo=  asymm.at(i).resiNr*99*amax+
+                  asymm.at(i).part*amax+
+                  n1/999.0l+
+                  sfac.indexOf(asymm.at(i).an)*10+
+                  (r1 / 50000.0l);//46656
+          atomSortMap.insertMulti(lodo,asymm.at(i));
+          break;
+        case 4:
+          lodo=
+          asymm.at(i).resiNr*99*amax+
+          asymm.at(i).part*amax+
+          n1/50000.0l+
+          ((110-asymm.at(i).an)/220)+
+          (r1 );//46656
+          atomSortMap.insertMulti(lodo,asymm.at(i));
+          t2++;
+          break;
+        case 5:
+          lodo=
+          asymm.at(i).molindex*9999*amax+
+          asymm.at(i).resiNr*99*amax+
+          asymm.at(i).part*amax+
+          n1/999.0l+
+          ((110-asymm.at(i).an))+
+          (r1 / 50000.0l);//46656
+          atomSortMap.insertMulti(lodo,asymm.at(i));
+          /*printf("%s %g\n", asymm.at(i).Label.toStdString().c_str(),asymm.at(i).molindex*9999*amax+
+              asymm.at(i).resiNr*99*amax+
+              asymm.at(i).part*amax+
+              n1/999.0+
+              ((110-asymm.at(i).an))+
+              (r1 / 50000.0));*/
+          break;
+        default:
+          atomSortMap.insert(i, asymm.at(i));
+          break;
+      }
+    }
+    {
+        QString s1 = tatze.Label.section('_',0,0);
+        s1.remove(0,chgl->mol->pse(tatze.an).size());
+        int n1 = s1.section(QRegExp("\\D"),0,0).toInt();
+        int r1 = 0 ;
+        char cc[10];
+        strncpy(cc,s1.section(QRegExp("\\d+"),1,-1).toStdString().c_str(),4);
+        for (size_t k=0; k<strlen(cc);k++) {r1*=256;r1+=(size_t)cc[k];}
+        //printf("VV= %Lf %d %d %d %d %d\n",lodo,tatze.resiNr,tatze.part,n1,(110-tatze.an),r1);
+    switch (sortierWeise){
+      case 1:
+        lodo=tatze.resiNr*99*amax+
+                tatze.part*amax+
+                n1+
+                ((110-tatze.an)/220.0l)+
+                (r1 / 50000.0l);//46656
+        break;
+      case 2:
+        lodo=tatze.resiNr*99*amax+
+                tatze.part*amax+
+                n1/999.0l+
+                ((110-tatze.an))+
+                (r1 / 50000.0l);//46656
+        break;
+      case 3:
+        lodo=  tatze.resiNr*99*amax+
+                tatze.part*amax+
+                n1/999.0l+
+                sfac.indexOf(tatze.an)*10+
+                (r1 / 50000.0l);//46656
+        break;
+      case 4:
+        lodo=
+        tatze.resiNr*99*amax+
+        tatze.part*amax+
+        n1/50000.0l+
+        ((110-tatze.an)/220)+
+        (r1 );//46656
+        break;
+      case 5:
+        lodo=
+        tatze.molindex*9999*amax+
+        tatze.resiNr*99*amax+
+        tatze.part*amax+
+        n1/999.0l+
+        ((110-tatze.an))+
+        (r1 / 50000.0l);//46656
+        break;
+    }
+    }
+    QList<long double> kys = atomSortMap.keys();
+    long double fi = kys.first();//, la = kys.last();
+    QString l="HKLF";
+    //printf("value = %Lf first = %Lf last = %Lf\n", lodo, fi, la);
+    if ((lodo>=fi)) {//
+        CEnvironment asymm2    =  atomSortMap.values();
+        int idx=0;
+        for (; (idx<kys.size())&& (lodo>kys.at(idx)); idx++){}
+        if (idx>0) idx--;
+      //  printf("idx %d\n",idx);
+        l = asymm2.at(idx).orginalLine.left(80).trimmed();
+        asymm2.clear();
+    }else{
+        QTextDocument *doc = this->document();
+        QTextCursor cursor = textCursor();
+        cursor.movePosition(QTextCursor::Start);
+        l=asymm.first().orginalLine.left(80).trimmed();
+        cursor=doc->find(l, cursor);
+        cursor.movePosition(QTextCursor::StartOfLine,QTextCursor::MoveAnchor);
+        cursor.movePosition(QTextCursor::Up,QTextCursor::MoveAnchor);
+        cursor.movePosition(QTextCursor::EndOfLine,QTextCursor::KeepAnchor);
+        l=cursor.selectedText();
+        cursor.clearSelection();
+        cursor.movePosition(QTextCursor::StartOfLine,QTextCursor::MoveAnchor);
+    }
+    kys.clear();
+    atomSortMap.clear();
+    return l;
+}
+
 void CodeEditor::sortAtoms(){
   if (chgl->mol->asymm.isEmpty()) return;
 
@@ -1570,14 +1730,16 @@ void CodeEditor::remark(int line){
 
 void CodeEditor::toggleRemarks(){
 QTextCursor cu=textCursor();
+if (!cu.hasSelection())return;
 cu.beginEditBlock();
-int start=0,end=0,hilf=0;
-QTextBlock block = firstVisibleBlock();
-while (block.isValid()){
-    if (block.contains(cu.selectionStart())) start= block.blockNumber();
-    if (block.contains(cu.selectionEnd())) end= block.blockNumber();		
-    block = block.next();
-}
+int start=-1,end=-1,hilf=0;
+start=cu.selectionStart();
+end=cu.selectionEnd();
+cu.setPosition(start);
+start=cu.blockNumber();
+cu.setPosition(end);
+end=cu.blockNumber();
+printf("start %d end %d\n",start,end);
 hilf=start;
 start=qMin(start,end);
 end=qMax(hilf,end);
@@ -1588,6 +1750,8 @@ for (int i=start; i<=end; i++) remark(i);
 }
 cu.endEditBlock();
 cu.clearSelection();
+cu.movePosition(QTextCursor::StartOfLine,QTextCursor::MoveAnchor);
+
 if (!cu.isNull()) setTextCursor(cu);
 }
 
@@ -1895,8 +2059,10 @@ void CodeEditor::keyPressEvent(QKeyEvent *e){
   // open the SHELXL help text:
   if (e->key() == Qt::Key_F1) {
     QTextCursor tc = textCursor();
-    tc.select(QTextCursor::WordUnderCursor);
-    QString txt = tc.selectedText().toUpper().split("_").first();
+    //tc.select(QTextCursor::WordUnderCursor);
+    tc.select(QTextCursor::LineUnderCursor);
+    QString txt = tc.selectedText().toUpper().left(4).trimmed();
+    printf("%s\n",txt.toStdString().c_str());
     if ( Window::isacommand(txt) >= 0 ) {
       QUrl help_url = QString("http://shelx.uni-goettingen.de/shelxl_html.php#%1").arg(txt);
       QDesktopServices::openUrl(help_url);
