@@ -1,6 +1,7 @@
 #include "dragdropatomsdlg.h"
-DragDropAtomsDialog::DragDropAtomsDialog(Molecule &mole, const QList<int> &reference, QList<int> *target, QWidget *parent, Qt::WindowFlags f)
+DragDropAtomsDialog::DragDropAtomsDialog(ChGL *gl, Molecule &mole, const QList<int> &reference, QList<int> *target, QWidget *parent, Qt::WindowFlags f)
     :QDialog(parent,f){
+    chgl=gl;
     DragDropAtoms *dda = new DragDropAtoms(mole,reference,target,parent);
     QScrollArea *qsa = new QScrollArea();
     qsa->setWidget(dda);
@@ -39,12 +40,81 @@ DragDropAtomsDialog::DragDropAtomsDialog(Molecule &mole, const QList<int> &refer
     rhla->addWidget(resiNrSpin);
     rhla->addWidget(resiResiClassL);
     rhla->addWidget(resiResiClass);
+    zoomIn = new QToolButton (this);
+    zoomIn-> setIcon(QIcon(":/icons/zoom-in.png"));
+    zoomIn->setShortcut(QKeySequence(Qt::ALT +Qt::Key_PageUp));
+    zoomIn->setText("Zoom +");
+    zoomIn->setToolTip("Zoom +");
+    zoomIn->setAutoRepeat(true);
+    zoomIn->setAutoRepeatDelay(150);
+    zoomIn->setAutoRepeatInterval(3);
+    zoomOut = new QToolButton(this);
+    zoomOut->setShortcut(QKeySequence(Qt::ALT +Qt::Key_PageDown));
+    zoomOut->setIcon(QIcon(":/icons/zoom-out.png"));
+    zoomOut->setText("Zoom -");
+    zoomOut->setToolTip("Zoom -");
+    zoomOut->setAutoRepeat(true);
+    zoomOut->setAutoRepeatDelay(150);
+    zoomOut->setAutoRepeatInterval(3);
 
+
+    rotLeft = new QToolButton(this);
+    rotLeft->setIcon(QIcon(":/icons/moveleft.png"));
+    rotLeft->setText("rotate couter clock wise");
+    rotLeft->setShortcut(QKeySequence(Qt::ALT + Qt::Key_Left));
+    rotLeft->setToolTip("rotate couter clock wise");
+    rotLeft->setAutoRepeat(true);
+    rotLeft->setAutoRepeatDelay(50);
+    rotLeft->setAutoRepeatInterval(3);
+
+
+    rotRight = new QToolButton(this);
+    rotRight->setIcon(QIcon(":/icons/moveright.png"));
+    rotRight->setText("rotate clock wise");
+    rotRight->setToolTip("rotate clock wise");
+    rotRight->setShortcut(QKeySequence(Qt::ALT + Qt::Key_Right));
+    rotRight->setAutoRepeat(true);
+    rotRight->setAutoRepeatDelay(50);
+    rotRight->setAutoRepeatInterval(3);
+
+    rotUp = new QToolButton(this);
+    rotUp->setShortcut(QKeySequence(Qt::ALT + Qt::Key_Up));
+
+    rotUp->setAutoRepeatDelay(50);
+    rotUp->setAutoRepeat(true);
+    rotUp->setAutoRepeatInterval(3);
+    rotDown = new QToolButton(this);
+    rotDown->setShortcut(QKeySequence(Qt::ALT + Qt::Key_Down));
+    rotDown->setAutoRepeatDelay(50);
+    rotDown->setAutoRepeat(true);
+    rotDown->setAutoRepeatInterval(3);
+
+    connect(zoomIn,SIGNAL(pressed ()),this,SLOT(zoomin()));
+    connect(zoomOut,SIGNAL(pressed ()),this,SLOT(zoomout()));
+    connect(rotRight,SIGNAL(pressed ()),this,SLOT(rotr()));
+    connect(rotLeft,SIGNAL(pressed ()),this,SLOT(rotl()));
+    connect(rotUp,SIGNAL(pressed ()),this,SLOT(rotu()));
+    connect(rotDown,SIGNAL(pressed ()),this,SLOT(rotd()));
+
+    QGridLayout *mola = new QGridLayout();
+    mola->addWidget(zoomIn,1,1);
+    mola->addWidget(zoomOut,0,0);
+    mola->addWidget(rotLeft,1,0);
+    mola->addWidget(rotRight,1,2);
+    mola->addWidget(rotUp,0,1);
+    mola->addWidget(rotDown,2,1);
+    QPixmap up = QPixmap(":/icons/moveright.png");
+    QTransform transform;
+    QTransform t90 = transform.rotate(-90);
+    QTransform t270 = transform.rotate(180);
+    rotUp->setIcon(up.transformed(t90));
+    rotDown->setIcon(up.transformed(t270));
     QVBoxLayout *lo = new QVBoxLayout();
     la->addWidget(qsa);
     la->addWidget(usageHint);
     lo->addLayout(la);
     lo->addLayout(rhla);
+    rhla->addLayout(mola);
     lo->addWidget(buttonBox);
     setLayout(lo);
     setMinimumWidth(190+usageHint->sizeHint().width());
@@ -60,12 +130,12 @@ void DragDropAtomsDialog::grossRC(const QString &text){
 void DragDropAtomsDialog::renameRNchanged(int ii){
   QMap<int,QString> resNrClass;
   for (int i=0; i<resiFinder->count(); i++){
-    QString resil=resiFinder->itemText(i);
-    resil.remove("RESI");
+    QString resil=resiFinder->itemText(i).toUpper();
+    resil.remove(QRegExp("^RESI"));
     QString resinr=resil;
     resil.remove(QRegExp("\\b\\d+\\b"));
-    resinr.remove(QRegExp("\\b\\D\\S+"));
-    int rn=resinr.toInt();
+    resinr.remove(resil.trimmed());
+    int rn=resinr.trimmed().toInt();
     resNrClass[rn]=resil.trimmed();
   }
   if (!ii) {
@@ -80,6 +150,37 @@ void DragDropAtomsDialog::renameRNchanged(int ii){
   }
 
 }
+
+void DragDropAtomsDialog::zoomin(){
+  chgl->zoom(0.1);
+  chgl->updateGL();
+}
+
+void DragDropAtomsDialog::zoomout(){
+  chgl->zoom(-0.1);
+  chgl->updateGL();
+}
+
+void DragDropAtomsDialog::rotr(){
+  chgl->rotY(-0.05);
+  chgl->updateGL();
+}
+
+void DragDropAtomsDialog::rotl(){
+  chgl->rotY(0.05);
+  chgl->updateGL();
+}
+
+void DragDropAtomsDialog::rotu(){
+  chgl->rotX(0.05);
+  chgl->updateGL();
+}
+
+void DragDropAtomsDialog::rotd(){
+  chgl->rotX(-0.05);
+  chgl->updateGL();
+}
+
 DragDropAtoms::DragDropAtoms(Molecule &mole, const QList<int> &reference, QList<int> *target, QWidget *parent)
     :QWidget(parent){
   m_mole = mole;
@@ -290,9 +391,9 @@ DragAtom::DragAtom(const int index,const QString &text,QColor c, QWidget *parent
   m_labelText=text;
   m_c=c;
   QFontMetrics metric(font());
-  QSize size = metric.size(Qt::TextSingleLine, text);
+  QSize size = metric.size(Qt::TextSingleLine, " "+ text+" ");
 
-  QImage image(size.width() + 12, size.height() + 12,
+  QImage image(size.width() + 14, size.height() + 14,
 		  QImage::Format_ARGB32_Premultiplied);
   image.fill(qRgba(0, 0, 0, 0));
 
