@@ -3,6 +3,7 @@
 
 #include <QtGui>
 #include "molecule.h"
+#include "chgl.h"
 /*! \brief DragAtom is an atom label that can be draged in the 'Inherit Labels' feature. 
  *
  * DragAtom is colored like the element the label refers to and represent the old label of the target molecule that 
@@ -30,16 +31,29 @@ private:
 class DragDropAtomsDialog : public QDialog {
 Q_OBJECT
 public:
-    DragDropAtomsDialog(Molecule &mole, const QList<int> &reference, QList<int> *target, QWidget *parent = 0, Qt::WindowFlags f = 0);
+    DragDropAtomsDialog(ChGL *gl, Molecule &mole, const QList<int> &reference, QList<int> *target, QWidget *parent = 0, Qt::WindowFlags f = 0);
     QLineEdit *resiResiClass;//!< A QLineEdit for the residue class which can be 4 letters long or 3 letters to be compatible to the pdb standard.
     QSpinBox *resiNrSpin;//!< A QSpinBox
     QComboBox *resiFinder;//!< A QComboBox that contains all existing residues found in the sructure.
     QPushButton * ok;//!< The Ok Button
+    QToolButton  *zoomIn;
+    QToolButton  *zoomOut;
+    QToolButton  *rotLeft;
+    QToolButton  *rotRight;
+    QToolButton  *rotUp;
+    QToolButton  *rotDown;
+    ChGL *chgl;
 signals:
          void pairs(const QString &);//!< When an atom label of the left column is clicked the signal is emitted to select the two atoms in the structure. @param _t1 the atom labels separated by a space. 
 public slots:
          void grossRC(const QString &text);//!< The text passed by this slot is capitalized an passed to the resiResiClass text. @param text Text to be capitalized and passed to resiResiClass.setText()
          void renameRNchanged(int ii);//!< called when the resiNrSpin changes the residue number if it is found in the structure the resiResiClass text gets updated and dissabled for user input. @params ii Residue number 
+         void zoomin();
+         void zoomout();
+         void rotr();
+         void rotl();
+         void rotu();
+         void rotd();
 };
 
 /*! \brief DragDropAtoms contains a list of DragAtoms to assign the labels of the reference molecule to the target molecule. 
