@@ -748,7 +748,8 @@ void DSREditWindow::setAtoms(){
         // and this has to be possible because of residues:
         //atomsEdit->undo();
         emit line_error(error);
-        return;
+        badLine = true;
+        //return;
       }
     }
     num++;
@@ -785,7 +786,8 @@ void DSREditWindow::setSelectedAtoms() {
   for (int i = 0; i < numselect; i++) {
     line.clear();
     atname.clear();
-    atname = m_mol->selectedatoms.at(i).Label.split('_')[0];
+    // The two split() make sure no illegal suffices remain on the labels:
+    atname = m_mol->selectedatoms.at(i).Label.split('_').at(0).split(QChar(187)).at(0);
     if (i == 0) {
       firstatom = atname;
     }
@@ -883,6 +885,13 @@ QStringList DSREditWindow::checkAtomLine(QStringList line, int num) {
       num2++;
     }
   }
+  if (badLine == true) {
+      addButton->setDisabled(true);
+      updateButton->setDisabled(true);
+  } else {
+      addButton->setEnabled(true);
+      updateButton->setEnabled(true);
+  }
   return line;
 }
 
@@ -914,8 +923,8 @@ void DSREditWindow::setRestraints() {
     return;
   }
   if (myRestraints[0].isEmpty()) {
-    //addButton->setDisabled(true);
-    //updateButton->setDisabled(true);
+    addButton->setDisabled(true);
+    updateButton->setDisabled(true);
     error = QString(tr("<font color=red><b>Please add at least one restraint to add/update the fragment.</font>"));
     emit line_error(error);
   } else {
