@@ -12,12 +12,6 @@
 #include "molecule.h"
 #include "chgl.h"
 #include "dsrgui.h"
-#if defined (Q_WS_MAC)
-#include <OpenGL/glu.h>
-//#include <glu.h>
-#else
-#include <GL/glu.h>
-#endif
 
 
 DSRGlWindow::DSRGlWindow(QWidget *parent, Molecule *m,
@@ -227,7 +221,7 @@ void DSRGlWindow::initializeGL(){
   glClearColor(0.6,0.6,0.6,1.0);
   glEnable(GL_DEPTH_TEST );
   glDepthFunc(GL_LEQUAL);
-  gluLookAt(0.0, 200, 50 ,   0.0, 0.0, 0.0,   0.0, -100, 400 );
+  gluLookAt_(0.0, 200, 50 ,   0.0, 0.0, 0.0,   0.0, -100, 400 );
   glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);
 }
 
@@ -236,7 +230,7 @@ void DSRGlWindow::resizeGL(int width, int height){
   glGetIntegerv(GL_VIEWPORT, vp);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
-  gluPerspective( 29.0, (double)width/height, 5.0, 8000.0 );
+  gluPerspective_( 29.0, (double)width/height, 5.0, 8000.0 );
 }
 
 QSize DSRGlWindow::minimumSizeHint() const
@@ -256,7 +250,7 @@ void DSRGlWindow::paintGL(){
   glGetIntegerv(GL_VIEWPORT, vp);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
-  gluPerspective( 29.0, (double)QGLWidget::width()/QGLWidget::height(), 5.0, 8000.0 );
+  gluPerspective_( 29.0, (double)QGLWidget::width()/QGLWidget::height(), 5.0, 8000.0 );
   glMatrixMode(GL_MODELVIEW);
   glPushMatrix();
   draw();
