@@ -125,9 +125,10 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   resnumbertext = new QString(tr("A residue number will be\nchosen automatically."));
   resiTextLabel = new QLabel();
   resiTextLabel->setText(*resnumbertext);
-  outtext = new QTextEdit;
+  outtext = new QTextBrowser;
+  outtext->setOpenExternalLinks(true);
   info = new QTextBrowser;
-  this->move(-this->width(), -this->height());
+  //this->move(-this->width(), -this->height());
   info->hide();
   info->setMinimumWidth(235);
   //info->setMaximumWidth(235);
@@ -258,12 +259,12 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   SearchInp->setFocus();
   // Has to be here, otherwise fragmentTableView is not initialized:
   QItemSelectionModel *sm = fragmentTableView->selectionModel();
-  this->move(m_shelxle->width()-this->width()-30, 30);
   this->show();
   if (!(sm == NULL)){  // prevents error about missing connection if DSR is not present
     connect(sm, SIGNAL(currentRowChanged(QModelIndex,QModelIndex)),
         this, SLOT(setFragName(QModelIndex)), Qt::UniqueConnection);
   }
+  this->move(m_shelxle->width()-this->width()-30, 30);
   this->resize(this->width()-2, this->height()-2);  // a trick to redraw the gl windows
   if (!(dsrVersion.toLatin1() == "0")) {
     outtext->append(QString("\nFound DSR version %1.").arg(dsrVersion));
@@ -555,24 +556,34 @@ void DSRGui::setToolTips() {
   openLastButton->setToolTip("Opens the .res file state before the last DSR fragment fit.");
 }
 
-QString DSRGui::textWrap(QString inText, int length, QString subsequent_indent) {
+QString DSRGui::textWrap(QString inText, QString indent) {
   //! returns a SHELXL compatible wrapped string (string =\\n string) in case of over 77 characters
-  //! line length
-  QString firstLine = "";
-  QString secondline = "";
-  if (inText.length() > length) {
-    foreach (QString chunk, inText.split(" ")) {
-      if ((firstLine.length()+(chunk+QString(" ")).length() < length) && ( secondline.isEmpty() )){
-        firstLine.append(chunk+QString(" "));
-      } else {
-        secondline.append(chunk+QString(" "));
+  //! line length.
+  //! The default of subsequent_indent is "=\n  "
+  int length = 70;  // 70 should be save in any case
+  QStringList line_list;
+  QStringList wrapped;
+  QStringList inText_list = inText.split(" ");
+  for (int i=0; i<inText_list.length(); i++) {
+    QString word = inText_list.at(i);
+    QString testline = line_list.join(" ") + " ";
+      if (QString(word + testline + indent).length() >= length) {
+        if (i < inText_list.length()-2) {
+          line_list.append(word + " " + indent);
+        } else {
+          line_list.append(word);
+        }
+        wrapped.append(line_list.join(" "));
+        line_list.clear();
+      } else{
+        line_list.append(word);
       }
-    }
-    return firstLine+QString("%1").arg(subsequent_indent)+secondline;
-  } else {
-    // nothing to wrap
-    return inText;
   }
+  if (!line_list.isEmpty()) {
+    wrapped.append(line_list.join(" "));
+  }
+  //qDebug() << wrapped.join(" ");
+  return wrapped.join(" ");
 }
 
 bool DSRGui::open_last_fileversion() {
@@ -586,6 +597,10 @@ bool DSRGui::open_last_fileversion() {
     QString saveHistFileName=QString("%1/%2saves/SAVEHIST").arg(currentpath.fileName()).arg(PROGRAM_NAME);
     QFile savehist(saveHistFileName);
     savehist.open(QIODevice::ReadOnly|QIODevice::Text);
+    if (!savehist.isReadable()) {
+        outtext->append("No last .res file found to load.");
+        return false;
+    }
     QString savehist_content = savehist.readAll();  //Entry|@|2011-03-08T13:32:19|@|b11.res|@|
     savehist.close();
     QRegExp re = QRegExp("Entry\\|@\\|\\w+-\\w+-\\w+:\\w+:\\w+\\|@\\|[^@]+@\\|");
@@ -1119,6 +1134,7 @@ void DSRGui::invertFrag(bool checked) {
   }
   //Also invert the selection of the atoms:
   for (int n=0; n<mygl->selFragAt.size(); n++) {
+    //this line is essential:
     mygl->selFragAt[n].pos = mygl->selFragAt[n].pos * rmat;
     mygl->selFragAt[n].pos.x *= -1;
     mygl->selFragAt[n].pos.y *= -1;
@@ -1270,7 +1286,7 @@ bool DSRGui::fitDSR() {
     return false;
   }
   QVector<int> previousLines = findDSRLines(reslist);
-  QString wrappedDSRLine = textWrap(combiDSRline, 75);
+  QString wrappedDSRLine = textWrap(combiDSRline);
   m_shelxle->insertDSRLine(wrappedDSRLine, DSRposition, previousLines);
   delete reslist;
   if (rigid) {
@@ -1281,18 +1297,18 @@ bool DSRGui::fitDSR() {
   if (norefine){
     option += " -n ";
   }
-  if (!runext and !invert) // the standard run without extra options
+  if (!runext && !invert) // the standard run without extra options
   {
     option += " -r ";
   }
-  else if (runext and !invert) {
+  else if (runext && !invert) {
     option += " -re ";
   }
-  else if (!runext and invert)
+  else if (!runext && invert)
   {
     option += " -t -r ";
   }
-  else if (runext and invert) {
+  else if (runext && invert) {
     option += " -t -re ";
   } else {
     qDebug() << "Unhandeled option case in DSRGui occoured!!";
@@ -1354,6 +1370,11 @@ bool DSRGui::runDSR(QString option, bool showresults, QString workdir) {
   }
   dsr.setProcessChannelMode(QProcess::MergedChannels);
   dsr.closeWriteChannel();
+  // Do not use this with fragment export:
+  if (!resfip.absolutePath().isEmpty() && workdir.isEmpty()) {
+    // Need to do this, because en empty path would cause dsr.start() to fail.
+    dsr.setWorkingDirectory(resfip.absolutePath());
+  }
   dsr.start(dsrpath, option.split(" ", QString::SkipEmptyParts));
   if (!dsr.waitForFinished()) {
     outtext->append("Unable to start DSR.");
@@ -1410,7 +1431,11 @@ void DSRGui::searchFragment(QString searchName) {
       fraglist.append(line.split(";;"));
     }
   }
-  displayFragmentsList(fraglist, "None");
+  if (fraglist.size() > 0) {
+    displayFragmentsList(fraglist, fraglist.at(0).at(0).toLatin1().toUpper());
+  } else {
+    displayFragmentsList(fraglist, "None");
+  }
 }
 
 bool DSRGui::isDSRVersionCorrect(QString version) {
@@ -1572,8 +1597,7 @@ void DSRGui::setExportDirDialog() {
   //! File dialog to define the directory for the res file
   //! exported by DSR
   export_dir = "";
-  export_dir = QFileDialog::getExistingDirectory(this,
-      tr("Export Fragment to ..."), tr("Directory"));
+  export_dir = QFileDialog::getExistingDirectory(this, tr("Export Fragment to ..."), tr("Directory"));
   if (QFile::exists(export_dir)){
     emit exportDirChanged(export_dir);
   }
