@@ -54,14 +54,14 @@ public:
   void checkForDSRexecutable(QSplashScreen *splash);
   QSize minimumSizeHint() const;
   QSize sizeHint() const;
-  static QString textWrap(QString inText, int = 75, QString = QString("=\n  "));
+  static QString textWrap(QString inText, QString indent = QString("=\n  "));  //! wraps text after specific amount of characters with a line ending
 private:
   QString getSelectedAtomsList();  //!< returns the list of the selected atoms in ShelXle
   QString getSelectedAtomsCoords();  //!< returns the coordinates of the selected atoms in ShelXle
   Molecule *m_molecule;            //!< A pointer to the molecule object in ShelXle
   Window *m_shelxle;               //!< The Window object of ShelXle
   QVector<QStringList> *fragmentsList;   //!< tag;;fullname;;line number;;db
-  QTextEdit *outtext;              //!< The message output field
+  QTextBrowser *outtext;              //!< The message output field
   QTextBrowser *info;              //!< Information table with bond distances of fitted fragments
   QLineEdit *SearchInp;            //!< Search input field
   QLineEdit *occEdit;              //!< Input field for the SHELXL occupancy
