@@ -457,6 +457,20 @@ void EacDlg::colorDLGenvidef(){
   mol->einstellung->setValue("enviBondColor",mol->enviBondColor);
   mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
   mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
+
+  mol->einstellung->beginWriteArray("HBondDonors",mol->theseAreDonors.size());
+  for (int i = 0; i < mol->theseAreDonors.size(); ++i) {
+    mol->einstellung->setArrayIndex(i);
+    mol->einstellung->setValue("Element",mol->pse(mol->theseAreDonors.at(i)));
+  }
+  mol->einstellung->endArray();
+
+  mol->einstellung->beginWriteArray("HBondAcceptors",mol->theseAreAcceptors.size());
+  for (int i = 0; i < mol->theseAreAcceptors.size(); ++i) {
+    mol->einstellung->setArrayIndex(i);
+    mol->einstellung->setValue("Element",mol->pse(mol->theseAreAcceptors.at(i)));
+  }
+  mol->einstellung->endArray();
   mol->einstellung->endGroup();
   }
   update();
@@ -493,6 +507,20 @@ void EacDlg::colorDLGenvibon(){
   mol->einstellung->setValue("enviBondColor",mol->enviBondColor);
   mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
   mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
+
+  mol->einstellung->beginWriteArray("HBondDonors",mol->theseAreDonors.size());
+  for (int i = 0; i < mol->theseAreDonors.size(); ++i) {
+    mol->einstellung->setArrayIndex(i);
+    mol->einstellung->setValue("Element",mol->pse(mol->theseAreDonors.at(i)));
+  }
+  mol->einstellung->endArray();
+
+  mol->einstellung->beginWriteArray("HBondAcceptors",mol->theseAreAcceptors.size());
+  for (int i = 0; i < mol->theseAreAcceptors.size(); ++i) {
+    mol->einstellung->setArrayIndex(i);
+    mol->einstellung->setValue("Element",mol->pse(mol->theseAreAcceptors.at(i)));
+  }
+  mol->einstellung->endArray();
   mol->einstellung->endGroup();
   }
   update();
@@ -530,6 +558,20 @@ void EacDlg::colorDLGenvihbo(){
   mol->einstellung->setValue("enviBondColor",mol->enviBondColor);
   mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
   mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
+
+  mol->einstellung->beginWriteArray("HBondDonors",mol->theseAreDonors.size());
+  for (int i = 0; i < mol->theseAreDonors.size(); ++i) {
+    mol->einstellung->setArrayIndex(i);
+    mol->einstellung->setValue("Element",mol->pse(mol->theseAreDonors.at(i)));
+  }
+  mol->einstellung->endArray();
+
+  mol->einstellung->beginWriteArray("HBondAcceptors",mol->theseAreAcceptors.size());
+  for (int i = 0; i < mol->theseAreAcceptors.size(); ++i) {
+    mol->einstellung->setArrayIndex(i);
+    mol->einstellung->setValue("Element",mol->pse(mol->theseAreAcceptors.at(i)));
+  }
+  mol->einstellung->endArray();
   mol->einstellung->endGroup();
   }
   update();
@@ -663,6 +705,20 @@ void EacDlg::unicolor(bool b){
   mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
   mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
 
+  mol->einstellung->beginWriteArray("HBondDonors",mol->theseAreDonors.size());
+  for (int i = 0; i < mol->theseAreDonors.size(); ++i) {
+    mol->einstellung->setArrayIndex(i);
+    mol->einstellung->setValue("Element",mol->pse(mol->theseAreDonors.at(i)));
+  }
+  mol->einstellung->endArray();
+
+  mol->einstellung->beginWriteArray("HBondAcceptors",mol->theseAreAcceptors.size());
+  for (int i = 0; i < mol->theseAreAcceptors.size(); ++i) {
+    mol->einstellung->setArrayIndex(i);
+    mol->einstellung->setValue("Element",mol->pse(mol->theseAreAcceptors.at(i)));
+  }
+  mol->einstellung->endArray();
+
   mol->einstellung->endGroup();
   update();
 }
@@ -677,6 +733,20 @@ void EacDlg::strengthChanged(double d){
   mol->einstellung->setValue("enviBondColor",mol->enviBondColor);
   mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
   mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
+
+  mol->einstellung->beginWriteArray("HBondDonors",mol->theseAreDonors.size());
+  for (int i = 0; i < mol->theseAreDonors.size(); ++i) {
+    mol->einstellung->setArrayIndex(i);
+    mol->einstellung->setValue("Element",mol->pse(mol->theseAreDonors.at(i)));
+  }
+  mol->einstellung->endArray();
+
+  mol->einstellung->beginWriteArray("HBondAcceptors",mol->theseAreAcceptors.size());
+  for (int i = 0; i < mol->theseAreAcceptors.size(); ++i) {
+    mol->einstellung->setArrayIndex(i);
+    mol->einstellung->setValue("Element",mol->pse(mol->theseAreAcceptors.at(i)));
+  }
+  mol->einstellung->endArray();
   mol->einstellung->endGroup();
   update();
 }
@@ -794,6 +864,20 @@ void EacDlg::importSettings(){
   mol->einstellung->setValue("enviBondColor",mol->enviBondColor);
   mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
   mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
+  mol->einstellung->beginWriteArray("HBondDonors",mol->theseAreDonors.size());
+  for (int i = 0; i < mol->theseAreDonors.size(); ++i) {
+    mol->einstellung->setArrayIndex(i);
+    mol->einstellung->setValue("Element",mol->pse(mol->theseAreDonors.at(i)));
+  }
+  mol->einstellung->endArray();
+
+  mol->einstellung->beginWriteArray("HBondAcceptors",mol->theseAreAcceptors.size());
+  for (int i = 0; i < mol->theseAreAcceptors.size(); ++i) {
+    mol->einstellung->setArrayIndex(i);
+    mol->einstellung->setValue("Element",mol->pse(mol->theseAreAcceptors.at(i)));
+  }
+  mol->einstellung->endArray();
+
   mol->einstellung->endGroup();
   //--------------------------------------
 }
@@ -880,6 +964,50 @@ void EacDlg::hbdistChanged(double){
     update();
 }
 
+void EacDlg::updateHBElemnts(){
+    QStringList accst=accLE->text().simplified().split(",",QString::SkipEmptyParts);
+    mol->theseAreAcceptors.clear();
+    for (int i=0; i<accst.size();i++){
+        int an=mol->getOZ(accst.at(i));
+        if (an>=0) mol->theseAreAcceptors.append(an);
+    }
+    QStringList donst=donLE->text().simplified().split(",",QString::SkipEmptyParts);
+    mol->theseAreDonors.clear();
+    for (int i=0; i<donst.size();i++){
+        int an=mol->getOZ(donst.at(i));
+        if (an>=0) mol->theseAreDonors.append(an);
+    }
+    donst.clear();
+    for (int i=0; i<mol->theseAreDonors.size(); i++) donst.append(mol->pse(mol->theseAreDonors.at(i)));
+    donLE->setText(donst.join(","));
+    accst.clear();
+    for (int i=0; i<mol->theseAreAcceptors.size(); i++) accst.append(mol->pse(mol->theseAreAcceptors.at(i)));
+    accLE->setText(accst.join(","));
+
+    mol->einstellung->beginGroup("Bonds");
+    mol->einstellung->setValue("BondColor",mol->bondColor);
+    mol->einstellung->setValue("BondStyle",mol->bondColorStyle);
+    mol->einstellung->setValue("BondStrength",mol->bondStrength);
+    mol->einstellung->setValue("enviBondColor",mol->enviBondColor);
+    mol->einstellung->setValue("enviHBColor",mol->enviHBColor);
+    mol->einstellung->setValue("enviDefaultColor",mol->enviDefaultColor);
+
+    mol->einstellung->beginWriteArray("HBondDonors",mol->theseAreDonors.size());
+    for (int i = 0; i < mol->theseAreDonors.size(); ++i) {
+      mol->einstellung->setArrayIndex(i);
+      mol->einstellung->setValue("Element",mol->pse(mol->theseAreDonors.at(i)));
+    }
+    mol->einstellung->endArray();
+
+    mol->einstellung->beginWriteArray("HBondAcceptors",mol->theseAreAcceptors.size());
+    for (int i = 0; i < mol->theseAreAcceptors.size(); ++i) {
+      mol->einstellung->setArrayIndex(i);
+      mol->einstellung->setValue("Element",mol->pse(mol->theseAreAcceptors.at(i)));
+    }
+    mol->einstellung->endArray();
+    mol->einstellung->endGroup();
+}
+
 void EacDlg::hbanglChanged(double){
     mol->einstellung->beginGroup("Bonds");
     mol->setHBondMaxDist(eacHBDist->value());
@@ -1057,6 +1185,22 @@ EacDlg::EacDlg(Molecule *externMole){
   QHBoxLayout *glt2= new QHBoxLayout();
   QHBoxLayout *glt5= new QHBoxLayout();
   QHBoxLayout *glt6= new QHBoxLayout();
+  QHBoxLayout *glt7= new QHBoxLayout();
+  QHBoxLayout *glt8= new QHBoxLayout();
+  QStringList accsl;
+  for (int i=0; i<mol->theseAreAcceptors.size(); i++) accsl.append(mol->pse(mol->theseAreAcceptors.at(i)));
+  accLE = new QLineEdit(accsl.join(","));
+  QLabel *accla = new QLabel("H-Bond Acceptor Elements");
+  glt7->addWidget(accLE);
+  glt7->addWidget(accla);
+
+  QStringList donsl;
+  for (int i=0; i<mol->theseAreDonors.size(); i++) donsl.append(mol->pse(mol->theseAreDonors.at(i)));
+  donLE = new QLineEdit(donsl.join(","));
+  QLabel *donla = new QLabel("H-Bond Donor Elements     ");
+  glt8->addWidget(donLE);
+  glt8->addWidget(donla);
+  connect(accLE,SIGNAL(editingFinished()),this,SLOT(updateHBElemnts()));
   glt2->addWidget(bondStrength);
   QLabel *bsl = new QLabel("Bond strength");
   QLabel *lodl = new QLabel("Level of detail");
@@ -1091,8 +1235,11 @@ EacDlg::EacDlg(Molecule *externMole){
   glt->addLayout(glt2);
   glt->addLayout(glt3);
   glt->addLayout(glt4);
-  glt->addLayout(glt6);
   glt->addLayout(glt5);
+  glt->addLayout(glt6);
+  glt->addLayout(glt7);
+  glt->addLayout(glt8);
+
   shaderUse = new QCheckBox("Use GLSL shader for atoms");
   if (mol->g_program&&mol->shaders_work){
     shaderUse->setChecked(mol->useShaders); 
