@@ -120,6 +120,7 @@ Q_OBJECT
   void importSettings();//!< import settings from a specified ini file.
   void hbdistChanged(double);//!< maximal length for H-bonds
   void hbanglChanged(double);//!< maximal angle for H-bonds
+  void updateHBElemnts();//!< H-bond accepor or donor list has changed
   protected slots:
   void accept () ;
   void reject () ;
@@ -133,6 +134,7 @@ Q_OBJECT
   QComboBox *eacProba;
   PSEWidget *psew;
   QPushButton *colorbut, *colorbut2,*colorbutEhb,*colorbutEbo,*colorbutEdf,*impbut,*expbut;
+  QLineEdit *donLE, *accLE;
   QGridLayout *eacGLO;
   //QComboBox *eacCB;
   QDoubleSpinBox *eacRAD;
