@@ -62,6 +62,25 @@ struct FNode {
   }
 };
 
+struct Polygn {
+  V3 vertex;
+  int n;
+  int ii[13];
+};
+
+struct Ort {
+  V3 vertex;
+  V3 normal;
+  GLfloat color;
+  char direct;
+};
+
+struct Node {
+  int index;
+  unsigned char flag; 
+  inline operator unsigned char (){return flag;}
+};
+
 //
 //!  FourXle is an QObject that loads a fcf 6 file and creates iso-surfaces in meshed style \inherit QObject 
 class FourXle:public QObject{
@@ -132,6 +151,29 @@ class FourXle:public QObject{
     V3 dx,//!< vector in a direction for each map voxel
        dy,//!< vector in b direction for each map voxel
        dz;//!< vector in c direction for each map voxel
+  QVector<Ort> Planorte;
+  QVector<Polygn> Planpgns;
+//  QList<double> data;
+  inline int Intersect( GLfloat& vm, GLfloat& vp ){
+    return vm*vp <= 0.0 && (vm<0.0 || vp<0.0);
+  }
+  Node *nodeX;
+  Node *nodeY;
+  Node *nodeZ;
+  void CalcPlaneVertex( int ix, int iy, int iz ,V3 n,V3 ap);
+  void makeFacesp(int nn, Node poly[] );
+  void MakeElementp( int ix, int iy, int iz ,int s1, int s2);
+  int IndexSelectedP( Node& node0, Node& node1, Node& node2, Node& node3 );
+  void findContour(QList<V3> &lines, GLfloat value);
+  void makePlane(QList<V3> &lines,int a1, int a2, int a3);
+  double min,max;
+  V3 orig,test3;
+  QLineEdit *contMapFile, *contourValueEdit, *contEPSFile;
+  QComboBox *aspectRatios, *centerIsOn;
+  QDoubleSpinBox *cScopeBx;
+  inline double winkel(V3 a,V3 b){
+    return acos((a.x*b.x+a.y*b.y+a.z*b.z)/(sqrt(a.x*a.x+a.y*a.y+a.z*a.z)*sqrt(b.x*b.x+b.y*b.y+b.z*b.z)));
+  }
     public slots:
       void bewegt(V3 v);
     void inimap();
@@ -192,7 +234,6 @@ signals:
     //    V3& VectorSelected( FNode& node0, FNode& node1, FNode& node2, FNode& node3);
     void MakeElement( int ix, int iy, int iz ,int s1, int s2, int faps);
     void makeFaces(int n, int faps, FNode poly[] );
-
     char titl[80];/*fcmax=0,f000=0,resmax=99999.0,*/
     void trimm(char s[]);
     void deletes(char *s, int count);
