@@ -355,7 +355,7 @@ void Highlighter::highlightError(const QStringList fnd){
 
 void Highlighter::highlightDupl(const CEnvironment &dupls){
     findRule.clear();
-    if (dupls.size()==0)return;
+    if (dupls.size()==0){rehighlight();return;}
   HighlightingRule rule;
   rule.format.setBackground(QColor("orange"));
   rule.format.setForeground(Qt::blue);
@@ -385,6 +385,17 @@ void Highlighter::highlightBlock(const QString &text) {
       index = text.indexOf(expression, index + length);
     }
   }
+  foreach (HighlightingRule rule, highlightingRules) {
+    if (!rule.Comment) continue;
+    QRegExp expression(rule.pattern);
+    int index = text.indexOf(expression);
+    while (index >= 0) {
+      int length = expression.matchedLength();
+      setFormat(index, length, rule.format);
+      index = text.indexOf(expression, index + length);
+     // printf("in editor height = %d\n",QFontMetrics(rule.format.font()).height());
+    }
+  }
   setCurrentBlockState(0);
 
   if (!outputstyle) {
