@@ -366,7 +366,7 @@ QColor HistoryWidget::farbverlauf(double wrt){
     {0.7f,0.6f,0.0f,1.0f},
     {0.7f,0.0f,1.0f,1.0f},
     {0.7f,0.0f,0.0f,1.0f}};
-  float nwrt=(wrt)/(100);
+  double nwrt=(wrt)/(100);
   nwrt=(nwrt>=1.0)?0.99999:nwrt;
   nwrt=(nwrt<=0.0)?0.00001:nwrt;
   lauf=(int (nwrt/0.2));
