@@ -50,6 +50,7 @@ public:
 signals:
     void message(const QString &);//!< emitts a text to the status bar
     void lofi(const QString &);//!< load a file version 
+    void saveHist();//!< a more prominent place for the SaveHistory ...
 public slots:
 void preview();//!< previewv of the first 30 lines
 void preview2();//!< preview the next 30 lines
@@ -65,6 +66,7 @@ private:
   size_t gesamtGr;
   QColor farbverlauf(double wrt);
   int maxwid;
+  int fh;//font height
   QString dirname;
 };
 
