@@ -8,13 +8,14 @@
 class IdealDefdenGenerator : public QThread{
 Q_OBJECT
   public:
-  IdealDefdenGenerator(ChGL *chgl_,FourXle *FX,const QString &dn, QObject * parent = 0 ){
+  IdealDefdenGenerator(ChGL *chgl_,FourXle *FX, QObject * parent = 0 ){
     chgl = chgl_;
     mommy = parent;// maybe I need it later?
-    dirName = QString(dn);
     fxle=FX;
   }
-
+  ~IdealDefdenGenerator(){
+     // printf("destruct ideal\n");
+  }
   void run() {
     /* expensive or blocking operation  */
     beloWriteCube();
@@ -22,10 +23,11 @@ Q_OBJECT
   double defden(V3 pos,CEnvironment &belo, QList<Matrix> &mi);
   void beloWriteCube();//bello braf!
   ChGL *chgl;
-  QObject *mommy;
-  QString dirName;
+  QObject *mommy;//parent
   FourXle *fxle;
-signals:
+
+signals:  
+  void progress(int v);
   void message(const QString &);//!< small text messages to the status bar.
 };
 #endif
