@@ -8,6 +8,16 @@
  * TODO:
  * - Make running SHELXL more visual. e.g. progress bar (especially while writing cif file)
  *
+ L.S.:
+ wR2 =  0.165168 before cycle   1 for   29437 data and   2607 /   2607 parameters
+ GooF = S =     1.509;     Restrained GooF =      1.434 for    3259 restraints
+ Mean shift/esd =   0.013  Maximum =     1.375 for  U23 C54        at 09:31:33
+ Max. shift = 0.008 A for C54        Max. dU =-0.010 for C54
+ *
+ CGLS:
+ wR2 =  0.165155 before cycle   1 for   29437 data and   2607 /   2607 parameters
+ GooF = S =     1.509;     Restrained GooF =      1.434 for    3257 restraints
+ Max. shift = 0.004 A for C54        Max. dU =-0.007 for C54
  */
 
 ListFileHandler::ListFileHandler(QString lfpath, QObject *parent) : QObject(parent)
@@ -90,7 +100,7 @@ QVector<QStringList> ListFileHandler::listfileparser() {
     }
     if (line.contains("RIGU")) {
       continue;  // leave out RIGU, it produces too many lines...
-    };
+    }
     if (splitline.size() < 2) continue;
     if (disag) {
       // in this case, the desired line is found:
@@ -294,6 +304,7 @@ XLOutputParser::XLOutputParser(QObject *parent) : QObject(parent) {
   //! Methods with "final" return the values after successful refinement.
   //!
   // The constructor:
+  ls_cycles = 0;
   listf_data.cmdline = "";
   listf_data.xlversion = "";
   listf_data.threads = "";
@@ -414,6 +425,9 @@ void XLOutputParser::fillListFileData(QString line) {
     listf_data.curGoof = goofs[0];
     listf_data.curRGoof = goofs[1];
   }
+  if (!goofs[2].isEmpty()) {
+    listf_data.nrestraints = goofs[2];
+  }
   if (!R1_4sig.isEmpty()) {
     listf_data.R1_4sig = R1_4sig;
   }
@@ -433,13 +447,13 @@ void XLOutputParser::fillListFileData(QString line) {
     listf_data.dU = maxshifts[2];
     listf_data.dUfor = maxshifts[3];
   }
-  if (!meanshifts[0].isEmpty() && !meanshifts[1].isEmpty()) {
+  if (!meanshifts[0].isEmpty() && !meanshifts[2].isEmpty()) {
     //shifts.append(meanshift);
     //shifts.append(maxshift_esd);
     //shifts.append(max_esd_shiftfor);
     listf_data.meanshift = meanshifts[0];
     listf_data.maxshift_esd = meanshifts[1];
-    listf_data.max_shift_esd_for = meanshifts[1];
+    listf_data.max_shift_esd_for = meanshifts[2];
   }
   if (!holevalues[0].isEmpty() && !holevalues[1].isEmpty() && !holevalues[2].isEmpty()
       && !holevalues[3].isEmpty()) {
@@ -468,14 +482,22 @@ void XLOutputParser::fillListFileData(QString line) {
 
 QString XLOutputParser::residualsTextDisplay(QString &line, int ls_cycles) {
   //! returns a html string to display the refinement results in a QLabel
+  this->ls_cycles = ls_cycles;
   fillListFileData(line);
   QString html_output = "";
   QString html_final = "";
   QString wr2line = "";
   QString shiftyellow = "";
+  QString shift_esd_yellow = "";
   QString dUyellow = "";
   QString cycleText = "";
   QString progressbar = "";
+  float restr_ratio = 0.0;
+  float data_to_param_ratio = 0.0;
+  if (!listf_data.data.isEmpty() && !listf_data.nrestraints.isEmpty() && !listf_data.all_parameters.isEmpty()){
+    restr_ratio = (listf_data.data.toDouble()+listf_data.nrestraints.toInt())/listf_data.all_parameters.toDouble();
+    data_to_param_ratio = listf_data.data.toFloat()/listf_data.all_parameters.toFloat();
+  }
   if (!listf_data.R1_4sig.isEmpty() && !listf_data.finalwR2.isEmpty()) { // final values:
     html_final = QString("<tr><td align=right><b><i>wR</i><sub>2</sub> = </b></td> <td><b> %2% </b>(all data) </td>"
                          "    <td align=right><b><i>R</i><sub>1</sub></b> [<i>I</i> > 4&sigma;<i>I</i>] = </td> <td><b>%1%</b> (%9% all data)</td></tr>"
@@ -520,6 +542,9 @@ QString XLOutputParser::residualsTextDisplay(QString &line, int ls_cycles) {
   if (qAbs(listf_data.maxshift.toDouble()) > 0.005) {
     shiftyellow = QString("bgcolor=#ffec99");
   }
+  if (qAbs(listf_data.maxshift_esd.toDouble()) > 0.01) {
+    shift_esd_yellow = QString("bgcolor=#ffec99");
+  }
   if (qAbs(listf_data.dU.toDouble()) > 0.005) {
     dUyellow = QString("bgcolor=#ffec99");
   }
@@ -544,8 +569,8 @@ QString XLOutputParser::residualsTextDisplay(QString &line, int ls_cycles) {
         "<table cellpadding=3% align=left>"
         "<tr><td colspan=2 align=left> <table><tr> %2 </tr></table> </td></tr>"
         "<tr><td> %3 threads on %4 processors </td></tr>"
-        "<tr><td> Using %5 data and %6 of %7 parameters (ratio %8) &nbsp; </td>"
-        "<td><i>R</i><sub>int</sub> = %9%, <i>R</i><sub>&sigma;</sub> = %10% </td></tr>"
+        "<tr><td> Using %5 data and %6 of %7 parameters (ratio %8; %11 with restraints) </td></tr>"
+        "<tr><td><i>R</i><sub>int</sub> = %9%, <i>R</i><sub>&sigma;</sub> = %10% </td></tr>"
         "</table>")
       .arg(listf_data.xlversion)            // 1
       .arg(progressbar)                     // 2
@@ -554,33 +579,56 @@ QString XLOutputParser::residualsTextDisplay(QString &line, int ls_cycles) {
       .arg(listf_data.data)                 // 5
       .arg(listf_data.current_parameters)   // 6
       .arg(listf_data.all_parameters)       // 7
-      .arg(listf_data.data.toDouble()/listf_data.all_parameters.toDouble(), 10, 'f', 1) // 8
-      .arg(listf_data.rint.toDouble()*100, 10, 'f', 2)     // 9
-      .arg(listf_data.rsigma.toDouble()*100, 10, 'f', 2)   // 10
+      .arg(data_to_param_ratio, 10, 'f', 1) // 8  data/restr. ratio
+      .arg(listf_data.rint.toFloat()*100, 10, 'f', 2)     // 9
+      .arg(listf_data.rsigma.toFloat()*100, 10, 'f', 2)   // 10
+      .arg(restr_ratio, 10, 'f', 1) // 11  (data+restraints)/parameter
       ;
 
+  QString maxshift_row = "";
+
+  if (!listf_data.maxshift_esd.isEmpty()) {
+    maxshift_row = QString("<tr><td align=right> Max. shift = </td> <td %1> %2 @  %3 </td> </tr>")
+      .arg(shift_esd_yellow)                 // 1 color of max shifting param.
+      .arg(listf_data.maxshift_esd)          // 2
+      .arg(listf_data.max_shift_esd_for)     // 3
+      ;
+  }
+
+  QString xyz_shift_row = "";
+
+  if (!listf_data.maxshift.isEmpty()) {
+    xyz_shift_row = QString("<tr><td align=right> Max. xyz shift =     </td> <td %1> %2 &Aring; @ %3     </td>"
+                          "    <td align=right> Max. &Delta;U =      </td> <td %4> %5 @ %6             </td></tr>")
+        .arg(shiftyellow)                // 1
+        .arg(listf_data.maxshift)        // 2
+        .arg(listf_data.maxshiftfor)     // 3
+        .arg(dUyellow)                   // 4
+        .arg(listf_data.dU)              // 5
+        .arg(listf_data.dUfor)           // 6
+      ;
+  }
+
   QString html_output2 = QString("<table cellpadding=2%>"
           "%1"
           "%2"
           "%3"
           "<tr><td align=right> <i>GooF</i> =             </td> <td> %4                     </td>"
           "    <td align=right  width=18%> Restr. <i>GooF</i> =  </td> <td> %5              </td></tr>"
-          "<tr><td align=right> Max. shift =              </td> <td %6> %7 &Aring; - %8     </td>"
-          "    <td align=right> Max. &Delta;U =           </td> <td %21> %9 - %10          </td></tr>"
+          "%6"
+          "%7"
           "</table>"
-          "<table><tr><td bgcolor=#ffec99><b> %11 </b></td></tr></table>"
+          "<table><tr><td bgcolor=#ffec99><b> %8 </b></td></tr></table>"
           "</body>")
           .arg(cycleText)                        // 1
           .arg(html_final)                       // 2
           .arg(wr2line)                          // 3 //wr2
           .arg(listf_data.curGoof)               // 4
           .arg(listf_data.curRGoof)              // 5
-          .arg(shiftyellow)                      // 6
-          .arg(listf_data.maxshift)              // 7
-          .arg(listf_data.maxshiftfor)           // 8
-          .arg(listf_data.dU)                    // 9
-          .arg(listf_data.dUfor)                 // 10
-          .arg(listf_data.warnings.join("<br>")) // 11
+          .arg(xyz_shift_row)                    // 6
+          .arg(maxshift_row)                     // 7
+          .arg(listf_data.warnings.join("<br>")) // 8
+
       ;
   if (!listf_data.wr2.isEmpty()) {
     html_output += html_output2;
@@ -707,6 +755,7 @@ QStringList XLOutputParser::xl_current_goof(QString line) {
   //! "GooF = S =     4.130;     Restrained GooF =      5.432 for    1662 restraints"
   QString goof;
   QString rgoof;
+  QString restraints;
   QStringList linesplit;
   QStringList goofs;
   if (line.contains("Restrained GooF") && line.contains("restraints")
@@ -715,9 +764,11 @@ QStringList XLOutputParser::xl_current_goof(QString line) {
     goof = linesplit.at(4);
     goof.remove(QChar(';'));
     rgoof = linesplit.at(8);
+    restraints = linesplit.at(10);
   }
   goofs.append(goof);
   goofs.append(rgoof);
+  goofs.append(restraints);
   return goofs;
 }
 
@@ -744,9 +795,9 @@ QStringList XLOutputParser::xl_current_meanshift_esd(QString line) {
   //! Returns the current shift per esd.
   //! "Mean shift/esd =   0.016  Maximum =    -8.976 for  U11 C6         at 09:36:30
   QStringList shifts;
-  QString meanshift;
-  QString maxshift_esd;
-  QString max_esd_shiftfor;
+  QString meanshift = "";
+  QString maxshift_esd = "";
+  QString max_esd_shiftfor = "";
   QStringList linesplit;
   if (line.contains("shift/esd") && line.contains("Maximum")
       && (line.split(" ", QString::SkipEmptyParts).size() >= 6) ) {
