@@ -44,6 +44,7 @@ struct LstData {
   QString all_parameters;       //! number of all possible refinement parameters
   QString curGoof;              //! current Goof for current cycle
   QString curRGoof;             //! current restraint Goof for current cycle
+  QString nrestraints;          //! number of restraints used in refinement
   QString finalwR2;             //! wR2 after refinement (all data)
   QString R1_4sig;              //! R1 after refinement with I > 4sig(I)
   QString R1_all;               //! R1 (all data) after refinement
@@ -98,6 +99,7 @@ class XLOutputParser : public QObject
 public:
   explicit XLOutputParser(QObject *parent = 0);
 private:
+  int ls_cycles;
   LstData listf_data;
   RGraph rgr;
   void fillListFileData(QString line);
