@@ -177,9 +177,13 @@ int main(int argv, char *args[]){
 #else
   qInstallMsgHandler(mh);
 #endif
+
+
   Window *window = new Window();
   window->show();
   int istat = app.exec();
+  printf("delete the main window now...\n");
   delete window;
+  printf("%d bye bye! Thanks for using!\n",istat);
   return istat;
 }
