@@ -155,13 +155,13 @@ QColor QPeakView::farbverlauf(double wrt){
     if (min>=max) max=min+0.001;
     int rot,gruen,blau,alpha;
     int lauf=0;
-    const float farbe[6][4]={{1.0,0.0,0.0,1.0},
-                          {1.0,1.0,0.0,1.0},
-                          {0.0,1.0,0.0,1.0},
-                          {0.0,1.0,1.0,1.0},
-                          {0.0,0.0,1.0,1.0},
-                          {1.0,0.0,1.0,1.0}};
-    float nwrt=(wrt-min)/(max-min);
+    const float farbe[6][4]={{1.0f,0.0f,0.0f,1.0f},
+                          {1.0f,1.0f,0.0f,1.0f},
+                          {0.0f,1.0f,0.0f,1.0f},
+                          {0.0f,1.0f,1.0f,1.0f},
+                          {0.0f,0.0f,1.0f,1.0f},
+                          {1.0f,0.0f,1.0f,1.0f}};
+    double nwrt=(wrt-min)/(max-min);
     nwrt=(nwrt>=1.0)?0.99999:nwrt;
     nwrt=(nwrt<=0.0)?0.00001:nwrt;
     lauf=(int (nwrt/0.2));
