@@ -110,6 +110,7 @@ class Window : public QMainWindow {
     QAction *sinaAct;
     QAction *recalcSDM;
     QAction *renamUpdateAct;
+    QAction *cntrPlot;
     QTextBrowser *brs;
     QProcess *runffmpeg;
     QLineEdit *ffmpegedt,*mp4file;
@@ -194,7 +195,11 @@ signals:
     void clearStructure();
     void closeEvent(QCloseEvent *event);//!<Tidys everything up and stores settings befor closing the ShelXle app.
     void configBeLos();//!< Configure BEDE LONE Objects style
-
+    void brwsEPS();
+    void everyPointOne();
+    void everyAIM();
+    void contourPlot();
+    void nocontourPlot();
     void colorButtonDialog();
     void convergeWght();//!<Tries to refine until the wheighting scheme converges.
     bool compareWGHTS(QString w1, QString w2, double tolerance = 0.001);//!<Compare 2 WGHT strings by value 
@@ -407,6 +412,7 @@ signals:
     QSpinBox *widthBox;       
     QSpinBox *heightBox;      
     QDoubleSpinBox *scalefBox;
+    QDoubleSpinBox *cStepBx;
     QDialog *scalDlg;
     QTextBrowser *infoKanal;
     QRadioButton *pserbt[110];
